#####################
Parameters Estimation
#####################

This module containts functions that allows us to estimate the vector of means 
and covariance matrix using several methods:

- Historical estimates.
- Estimates using exponencial weighted moving averages (EWMA).
- Robust estimates of the covariance matrix like shrinkage or oracle method.
- The Black Litterman model.
- Factors models to estimate the vector of means and covariance matrix.


Module Functions
================

.. automodule:: ParamsEstimation
   :members:
   :private-members:
   :member-order: bysource


Bibliography
============
.. bibliography:: biblio.bib
   :style: unsrt
   :labelprefix: B
   :keyprefix: b-